@@ -1,4 +1,3 @@
-
 '''Tools for Bright Edge eServices developments & projects
 
 These tools was designed for the use in the Bright Edge eServices echo system.
@@ -96,7 +95,11 @@ def exec_batch_in_session(
         ext = 'bat'
         contents = ''
     else:
-        print(colored('Unknown OS ({})\nSystem terminated!'.format(beeutils.get_os()), 'red'))
+        print(
+            colored(
+                'Unknown OS ({})\nSystem terminated!'.format(beeutils.get_os()), 'red'
+            )
+        )
         sys.exit()
 
     if not p_script_name:
@@ -107,15 +110,18 @@ def exec_batch_in_session(
     if beeutils.get_os() == beeutils.MACOS:
         batch_pth.chmod(0o777)
     if p_verbose:
-        print(msg_info('==[Start {0}]====\n{1}==[ End {0} ]===='.format(batch_pth, contents)))
+        print(
+            msg_info(
+                '==[Start {0}]====\n{1}==[ End {0} ]===='.format(batch_pth, contents)
+            )
+        )
     compl_proc = exec_cmd(script, p_crash, p_verbose=p_verbose, p_shell=p_shell)
     if os.path.isfile(batch_pth):
         os.remove(batch_pth)
-        pass
     return compl_proc
 
 
-def exec_batch(p_batch, p_verbose = False):
+def exec_batch(p_batch, p_verbose=False):
     '''Execute a batch.
 
     Each command will be executed independantly of the previous one i.e it
@@ -140,7 +146,7 @@ def exec_batch(p_batch, p_verbose = False):
     success = True
     # c_cmd = 1
     for cmd in p_batch:
-        rc = exec_cmd(cmd, p_verbose = p_verbose)
+        rc = exec_cmd(cmd, p_verbose=p_verbose)
         if rc is not True:
             success = False
     return success
@@ -186,7 +192,11 @@ def exec_cmd(p_cmd, p_crash=True, p_shell=None, p_verbose=False) -> bool:
     elif beeutils.get_os() == beeutils.WINDOWS and not p_shell:
         shell = True
     elif beeutils.get_os() not in [beeutils.WINDOWS, beeutils.LINUX, beeutils.MACOS]:
-        print(colored('Unknow OS ({})\nSystem terminated!'.format(beeutils.get_os()), 'red'))
+        print(
+            colored(
+                'Unknow OS ({})\nSystem terminated!'.format(beeutils.get_os()), 'red'
+            )
+        )
         sys.exit()
     else:
         shell = p_shell
@@ -299,11 +309,14 @@ def example_scripting():
     t_file.touch(mode=0o666, exist_ok=True)
     t_file = tmp_t1 / Path('t.tmp')
     t_file.touch(mode=0o666, exist_ok=True)
-    success = beeutils.rm_tree(tmp_test, p_crash = True) and success
+    success = beeutils.rm_tree(tmp_test, p_crash=True) and success
 
     # Attempt to remove a temporary locked file.
     venv_name = 'new-project'
-    success = beeutils.rm_temp_locked_file(beevenv.get_dir(beeutils.get_tmp_dir(), venv_name)) and success
+    success = (
+        beeutils.rm_temp_locked_file(beevenv.get_dir(beeutils.get_tmp_dir(), venv_name))
+        and success
+    )
 
     # Read an option from an ini for a particular os and setup
     cnf = configparser.ConfigParser()
@@ -319,10 +332,12 @@ def example_scripting():
             }
         }
     )
-    os_system_flder = beeutils.select_os_dir_from_config(cnf, 'Folders', 'MyFolderOnSystem')
+    os_system_flder = beeutils.select_os_dir_from_config(
+        cnf, 'Folders', 'MyFolderOnSystem'
+    )
     print(os_system_flder)
     success = os_system_flder and success
-    beeutils.result_rep(success, p_comment= 'Done')
+    beeutils.result_rep(success, p_comment='Done')
     return success
 
 
@@ -349,7 +364,7 @@ def do_examples(p_cls=True):
 
     # Initiate the Archiver
     success = True
-    b_tls = beeutils.Archiver(_PROJ_NAME, _PROJ_VERSION, _PROJ_DESC, _PROJ_PATH)
+    b_tls = beeutils.Archiver(_PROJ_DESC, _PROJ_PATH)
     b_tls.print_header(p_cls=p_cls)
     success = example_scripting() and success
     b_tls.print_footer()
