@@ -1,4 +1,3 @@
-
 '''Tools for Bright Edge eServices developments & projects
 
 These tools was designed for the use in the Bright Edge eServices echo system.
@@ -25,6 +24,8 @@ import os
 from pathlib import Path
 import shutil
 import sys
+import tempfile
+
 # from beetools.beemsg import ok as msg_ok, error as msg_error
 from beetools.beearchiver import Archiver, msg_ok, msg_error
 
@@ -106,23 +107,43 @@ CODEC_LIST = [
     ['euc_jp', 'eucjp, ujis, u-jis', 'Japanese'],
     ['euc_jis_2004', 'jisx0213, eucjis2004', 'Japanese'],
     ['euc_jisx0213', 'eucjisx0213', 'Japanese'],
-    ['euc_kr', 'euckr, korean, ksc5601, ks_c-5601, ks_c-5601-1987, ksx1001, ks_x-1001', 'Korean'],
-    ['gb2312', 'chinese, csiso58gb231280, euc-cn, euccn, eucgb2312-cn, gb2312-1980, gb2312-80, iso-ir-58', 'Simplified Chinese'],
+    [
+        'euc_kr',
+        'euckr, korean, ksc5601, ks_c-5601, ks_c-5601-1987, ksx1001, ks_x-1001',
+        'Korean',
+    ],
+    [
+        'gb2312',
+        'chinese, csiso58gb231280, euc-cn, euccn, eucgb2312-cn, gb2312-1980, gb2312-80, iso-ir-58',
+        'Simplified Chinese',
+    ],
     ['gbk', '936, cp936, ms936', 'Unified Chinese'],
     ['gb18030', 'gb18030-2000', 'Unified Chinese'],
     ['hz', 'hzgb, hz-gb, hz-gb-2312', 'Simplified Chinese'],
     ['iso2022_jp', 'csiso2022jp, iso2022jp, iso-2022-jp', 'Japanese'],
     ['iso2022_jp_1', 'iso2022jp-1, iso-2022-jp-1', 'Japanese'],
-    ['iso2022_jp_2', 'iso2022jp-2, iso-2022-jp-2', 'Japanese, Korean, Simplified Chinese, Western Europe, Greek'],
+    [
+        'iso2022_jp_2',
+        'iso2022jp-2, iso-2022-jp-2',
+        'Japanese, Korean, Simplified Chinese, Western Europe, Greek',
+    ],
     ['iso2022_jp_2004', 'iso2022jp-2004, iso-2022-jp-2004', 'Japanese'],
     ['iso2022_jp_3', 'iso2022jp-3, iso-2022-jp-3', 'Japanese'],
     ['iso2022_jp_ext', 'iso2022jp-ext, iso-2022-jp-ext', 'Japanese'],
     ['iso2022_kr', 'csiso2022kr, iso2022kr, iso-2022-kr', 'Korean'],
-    ['latin_1', 'iso-8859-1, iso8859-1, 8859, cp819, latin, latin1, L1', 'Western Europe'],
+    [
+        'latin_1',
+        'iso-8859-1, iso8859-1, 8859, cp819, latin, latin1, L1',
+        'Western Europe',
+    ],
     ['iso8859_2', 'iso-8859-2, latin2, L2', 'Central and Eastern Europe'],
     ['iso8859_3', 'iso-8859-3, latin3, L3', 'Esperanto, Maltese'],
     ['iso8859_4', 'iso-8859-4, latin4, L4', 'Baltic languages'],
-    ['iso8859_5', 'iso-8859-5, cyrillic', 'Bulgarian, Byelorussian, Macedonian, Russian, Serbian'],
+    [
+        'iso8859_5',
+        'iso-8859-5, cyrillic',
+        'Bulgarian, Byelorussian, Macedonian, Russian, Serbian',
+    ],
     ['iso8859_6', 'iso-8859-6, arabic', 'Arabic'],
     ['iso8859_7', 'iso-8859-7, greek, greek8', 'Greek'],
     ['iso8859_8', 'iso-8859-8, hebrew', 'Hebrew'],
@@ -138,10 +159,18 @@ CODEC_LIST = [
     ['koi8_t', 'Tajik New in version 3.5.'],
     ['koi8_u', 'Ukrainian'],
     ['kz1048', 'kz_1048, strk1048_2002, rk1048', 'Kazakh New in version 3.5.'],
-    ['mac_cyrillic', 'maccyrillic', 'Bulgarian, Byelorussian, Macedonian, Russian, Serbian'],
+    [
+        'mac_cyrillic',
+        'maccyrillic',
+        'Bulgarian, Byelorussian, Macedonian, Russian, Serbian',
+    ],
     ['mac_greek', 'macgreek', 'Greek'],
     ['mac_iceland', 'macicelandIcelandic'],
-    ['mac_latin2', 'maclatin2, maccentraleurope, mac_centeuro', 'Central and Eastern Europe'],
+    [
+        'mac_latin2',
+        'maclatin2, maccentraleurope, mac_centeuro',
+        'Central and Eastern Europe',
+    ],
     ['mac_roman', 'macroman, macintosh', 'Western Europe'],
     ['mac_turkish', 'macturkish', 'Turkish'],
     ['ptcp154', 'csptcp154, pt154, cp154, cyrillic-asian', 'Kazakh'],
@@ -156,7 +185,7 @@ CODEC_LIST = [
     ['utf_16_le', 'UTF-16LE', 'all languages'],
     ['utf_7', 'U7, unicode-1-1-utf-7', 'all languages'],
     ['utf_8', 'U8, UTF, utf8, cp65001', 'all languages'],
-    ['utf_8_sig', '', 'all languages']
+    ['utf_8_sig', '', 'all languages'],
 ]
 
 
@@ -191,7 +220,7 @@ def get_os() -> str:
     return curr_os
 
 
-def get_tmp_dir() -> Path:
+def get_tmp_dir(p_prefix=None) -> Path:
     '''Return os related temporary folder for user.
 
     Parameters
@@ -209,14 +238,11 @@ def get_tmp_dir() -> Path:
     PosixPath('/tmp')
 
     '''
-    temp = None
-    if get_os() == LINUX:
-        temp = '/tmp'
-    elif get_os() == WINDOWS:
-        temp = os.environ['TEMP']
-    elif get_os() == MACOS:
-        temp = os.environ['TMPDIR']
-    return Path(temp)
+    if p_prefix:
+        temp_dir = Path(tempfile.mkdtemp(prefix=p_prefix))
+    else:
+        temp_dir = Path(tempfile.mkdtemp())
+    return temp_dir
 
 
 def is_struct_the_same(p_x, p_y, p_ref='') -> bool:
@@ -354,16 +380,16 @@ def rm_temp_locked_file(p_file_path) -> bool:
             if p_file_path.is_dir():
                 shutil.rmtree(p_file_path)
             success = True
-        except shutil.Error as err:
+        except shutil.Error:
             crash_retry_cntr += 1
-        except PermissionError as err:
+        except PermissionError:
             crash_retry_cntr += 1
         else:
             crash_retry_cntr = CRASH_RETRY
     return success
 
 
-def rm_tree(p_pth, p_crash = True):
+def rm_tree(p_pth, p_crash=True):
     '''Remove a tree structure
 
     Parameters
@@ -386,7 +412,6 @@ def rm_tree(p_pth, p_crash = True):
     success = False
     # tree = list(p_pth.glob('**/*'))
     # not_empty = []
-    locked_file_lst = []
     crash_retry_cntr = 0
     # success = False
     while crash_retry_cntr < CRASH_RETRY and not success:
@@ -397,34 +422,17 @@ def rm_tree(p_pth, p_crash = True):
                     file_pth = os.path.join(root, file)
                     os.remove(file_pth)
                     success = True and success
-                except PermissionError as err:
-                    # locked_file_lst.append(file_pth)
+                except PermissionError:
                     success = False
             for dir in dirs:
                 try:
                     dir_pth = os.path.join(root, dir)
                     os.rmdir(dir_pth)
                     success = True and success
-                except OSError as err:
+                except OSError:
                     success = False
         crash_retry_cntr += 1
 
-    # while len(tree) > 0:
-    #     for src in tree:
-    #         if src.is_file():
-    #             try:
-    #                 src.unlink()
-    #             except PermissionError as err:
-    #                 locked_file_lst.append(src)
-    #                 rm_temp_locked_file(src)
-    #         elif src.is_dir():
-    #             try:
-    #                 src.rmdir()
-    #             except OSError as err:
-    #                 if src.exists():
-    #                     not_empty.append(src)
-    #     tree = not_empty.copy()
-    #     not_empty = []
     if p_pth.exists():
         try:
             p_pth.rmdir()
@@ -492,9 +500,7 @@ def select_os_dir_from_config(p_config, p_section, p_option) -> Path:
     if not dir:
         print(
             msg_error(
-                'select_os_dir_from_config not found: {}:{}'.format(
-                    p_section, p_option
-                )
+                'select_os_dir_from_config not found: {}:{}'.format(p_section, p_option)
             )
         )
     return dir
@@ -525,14 +531,14 @@ def example_tools():
     print('The current os is {}'.format(get_os()))
     tmp_dir = get_tmp_dir() / 'test'
     print('created a temporary folder {}'.format(tmp_dir))
-    success = rm_tree(tmp_dir, p_crash = True) and success
+    success = rm_tree(tmp_dir, p_crash=True) and success
 
     # Usage of is_struct_the_same
     x = [1, 2]
     y = [1, 2]
     print('x={}'.format(x))
     print('y={}'.format(y))
-    print(is_struct_the_same(x,y))
+    print(is_struct_the_same(x, y))
 
     x = {1: 'One', 2: 'Two'}
     y = {2: 'Two', 1: 'One'}
@@ -548,7 +554,7 @@ def example_tools():
     # Attempt to remove a temporary locked file.
     tmp_dir = get_tmp_dir()
     tmp_pth = tmp_dir / 'dropboxfile.txt'
-    with open(tmp_pth, 'w+' ) as locked_file:
+    with open(tmp_pth, 'w+') as locked_file:
         for i in range(1000000):
             locked_file.write(str(i))
     success = rm_temp_locked_file(tmp_pth) and success
@@ -597,8 +603,8 @@ def do_examples(p_app_path=None, p_cls=True):
     '''
 
     # Initiate the Archiver
-    b_tls = Archiver(_PROJ_NAME, _PROJ_VERSION, _PROJ_DESC, p_app_path)
-    b_tls.print_header(p_cls = p_cls)
+    b_tls = Archiver(_PROJ_DESC, p_app_path)
+    b_tls.print_header(p_cls=p_cls)
     success = example_tools()
     b_tls.print_footer()
     if success:
